*****
smore
*****

Release v\ |version| (:ref:`Changelog <changelog>`)

.. warning::
    Nothing here is stable. Right now this is a playground to try out some ideas. Follow its progress on `GitHub <https://github.com/marshmallow-code/smore>`_.

A collection of utilities for designing and documenting RESTful APIs.

- `smore @ GitHub <https://github.com/marshmallow-code/smore>`_
- `Issue Tracker <https://github.com/marshmallow-code/smore/issues>`_

Modules
=======

.. toctree::
    :maxdepth: 2

    modules/apispec
    modules/swagger


Project Info
============

.. toctree::
   :maxdepth: 1

   changelog
   authors
   contributing
   license
